@@ -650,7 +650,7 @@ class Series:
         self.tag = 'Series'
         
         self.contours = self.popcontours(root)
-        self.sections = [] #Sorted in reconstructmergetool.getsections()
+        self.sections = [] #Sorted in self.getSectionsXML()
         
         self.index = self.popindex(root)
         self.viewport = self.popviewport(root)
@@ -774,10 +774,16 @@ class Series:
         '''Allows use of != between multiple objects'''
         return self.output()[0] != other.output()[0] and self.output()[1] != other.output()[1]
 # Accessors
-    def getObjectHierarchy(self, dendrites, protrusions, traces, others): #=== others not implemented
+    def getObjectHierarchy(self, dendrites, protrusions, traces, others):
         '''Returns a single hierarchical dictionary with data for each object not in others list'''
+        
+        # Print out objects in 'others' list; these are not included in the resulting hierarcy dict
+        print('The following objects were not classified and thus ignored:')
+        for thing in others:
+            print('\t'+str(thing))
+        
+        # Combine lists (except 'others') into a hierarchical dictionary
         hierarchy = {}
-        # Combine lists into a hierarchical dictionary
         for dendrite in dendrites:
             # 1) Create rObject for dendrite
             denObj = rObject(name=dendrite, series=self, tag='dendrite')
@@ -802,7 +808,7 @@ class Series:
         return hierarchy
     def getObjectLists(self):
         '''Returns lists of dendrite names, protrusion names, trace names, and a list of other objects in series'''
-        dendrite_expression = 'd[0-9]{2}$' # represents base dendrite name (d##)
+        dendrite_expression = 'd[0-9]{2}' # represents base dendrite name (d##)
         protrusion_expression = 'd[0-9]{2}p[0-9]{2}$' # represents base protrusion name (d##p##)
         trace_expression = 'd[0-9]{2}[a-z]{1,6}' # represents trace name (d##
         
@@ -820,15 +826,18 @@ class Series:
             for contour in section.contours:
                 # Dendrite
                 if dendrite_expression.match(contour.name) != None:
-                    dendrites.append(contour.name)
+                    dendrites.append(contour.name[0:3])
                 # Protrusion
-                elif protrusion_expression.match(contour.name) != None:
+                if protrusion_expression.match(contour.name) != None:
                     protrusions.append(contour.name)
                 # Trace
-                elif trace_expression.match(contour.name) != None:
+                if (trace_expression.match(contour.name) != None and
+                    protrusion_expression.match(contour.name) == None):
                     traces.append(contour.name)
                 # Everything else
-                else:
+                if (dendrite_expression.match(contour.name) == None and
+                    protrusion_expression.match(contour.name) == None and
+                    trace_expression.match(contour.name) == None):
                     others.append(contour.name)
         return list(set(dendrites)), list(set(protrusions)), list(set(traces)), list(set(others))
     def output(self):
